==> injecty-0.1.0.tgz: package/lib/utils.js <==
{
    var _ns_ = {
        id: 'injecty.lib.macros',
        doc: void 0
    };
}
void 0;
void 0;
void 0;
{
    var _ns_ = {
        id: 'promitto.lib.utils',
        doc: void 0
    };
}
var toString = Object.prototype.toString;
var argsRegex = new RegExp('^function(\\s*)(\\w*)[^(]*\\(([^)]*)\\)', 'm');
var fnNameRegex = new RegExp('^function\\s*(\\w+)\\s*\\(', 'i');
var isFn = exports.isFn = function isFn(o) {
    return typeof(o) === 'function';
};
var isStr = exports.isStr = function isStr(o) {
    return toString.call(o) === '[object String]';
};
var isObj = exports.isObj = function isObj(o) {
    return toString.call(o) === '[object Object]';
};
var isArr = exports.isArr = function isArr(o) {
    return toString.call(o) === '[object Array]';
};
var toArr = exports.toArr = function toArr(o) {
    return Array.prototype.slice.call(o);
};
var chain = exports.chain = function chain(obj, fn) {
    return function () {
        fn.apply(void 0, arguments);
        return obj;
    };
};
var fnName = exports.fnName = function fnName(lambda) {
    return isFn(lambda) ? lambda.name ? lambda.name : function () {
        var nameø1 = fnNameRegex.exec(lambda.toString());
        return nameø1 && nameø1[1] ? nameø1[1] : void 0;
    }.call(this) : void 0;
};
var parseArgs = exports.parseArgs = function parseArgs(lambda) {
    return isFn(lambda) ? function () {
        var matchesø1 = argsRegex.exec(lambda.toString());
        return matchesø1 && matchesø1[3] ? matchesø1[3].split(new RegExp('\\s*,\\s*')) : void 0;
    }.call(this) : void 0;
};

==> injecty-0.1.3.tgz: package/lib/utils.js <==
{
    var _ns_ = {
        id: 'injecty.lib.macros',
        doc: void 0
    };
}
void 0;
void 0;
void 0;
{
    var _ns_ = {
        id: 'promitto.lib.utils',
        doc: void 0
    };
}
var toString = Object.prototype.toString;
var argsRegex = new RegExp('^function(\\s*)(\\w*)[^(]*\\(([^)]*)\\)', 'm');
var fnNameRegex = new RegExp('^function\\s*(\\w+)\\s*\\(', 'i');
var isFn = exports.isFn = function isFn(o) {
    return typeof(o) === 'function';
};
var notEmpty = function notEmpty(o) {
    return (o === void 0 ? false : true) && (o === null ? false : true);
};
var isStr = exports.isStr = function isStr(o) {
    return notEmpty(o) && toString.call(o) === '[object String]';
};
var isObj = exports.isObj = function isObj(o) {
    return notEmpty(o) && toString.call(o) === '[object Object]';
};
var isArr = exports.isArr = function isArr(o) {
    return notEmpty(o) && toString.call(o) === '[object Array]';
};
var chain = exports.chain = function chain(obj, fn) {
    return function () {
        fn.apply(void 0, arguments);
        return obj;
    };
};
var fnName = exports.fnName = function fnName(lambda) {
    return isFn(lambda) ? lambda.name ? lambda.name : function () {
        var nameø1 = fnNameRegex.exec(lambda.toString());
        return nameø1 && nameø1[1] ? nameø1[1] : void 0;
    }.call(this) : void 0;
};
var parseArgs = exports.parseArgs = function parseArgs(lambda) {
    return isFn(lambda) ? function () {
        var matchesø1 = argsRegex.exec(lambda.toString());
        return matchesø1 && matchesø1[3] ? matchesø1[3].split(new RegExp('\\s*,\\s*')) : void 0;
    }.call(this) : void 0;
};
